==> rc-menu-4.13.0.jar: META-INF/resources/webjars/rc-menu/4.13.0/HISTORY.md <==
# History
----

## 4.13.0 / 2016-07-22

- support submenu-selected

## 4.12 / 2016-05-05

- make submenu active only title is hovered when inline

## 4.11.0 / 2016-04-27

- add onMouseEnter/onTitleMouseLeave/onTitleClick/...

## 4.10.0 / 2016-01-20

- use es6 export

## 4.9.0 / 2015-12-25
- add keyPath to onOpen/onClose argument info

## 4.6.0 / 2015-09-16
- add keyPath to onClick argument info

## 4.5.0 / 2015-09-14
- does not hide submenu when click(use onClick to set openKeys to [] if you want)

## 4.4.0 / 2015-08-13
- add openAnimation/openTransitionName prop

## 4.3.0 / 2015-08-13
- make selectedKeys openedKeys controllable
- add closeSubMenuOnMouseLeave/onOpen/onClose props

## 4.1.0 / 2015-08-11
- remove openOnHover for SubMenu
- add openSubMenuOnMouseEnter prop for Menu

## 4.0.0 / 2015-08-10

- add props: mode (horizontal, vertical, inline) for Menu
- add defaultSelectedKeys, make selectedKeys controllable
- change param of onSelect onDeselect

## 3.5.0 / 2015-08-06

add props: vertical/horizontal for Menu, align for SubMenu

## 3.4.0 / 2015-06-17

`improved` [#9](https://github.com/react-component/menu/issues/9) allow not set key for menuitem

`new` [#10](https://github.com/react-component/menu/issues/10) support MenuItemGroup

## 3.3.0 / 2015-06-08

`new` add Menu.Divider Component

## 3.1.0 / 2015-03-26

`improved` [#5](https://github.com/react-component/menu/issues/5) support selected and disabled for menuitem simultaneously

## 3.0.0 / 2015-03-17

support react 0.13 and es6

## 2.2.0 / 2015-01-29

`new` [#3](https://github.com/react-component/menu/issues/3) support scrollIntoView if menu is scrollable

`new` [#2](https://github.com/react-component/menu/issues/2) support multiple prop and onDeselect callback

==> rc-menu-6.2.6.jar: META-INF/resources/webjars/rc-menu/6.2.6/HISTORY.md <==
# History
----

## 6.0.0 / 2017-10-30

- Replace openSubMenuOnMouseEnter/closeSubMenuOnMouseLeave with triggerSubMenuAction
- Add subMenuCloseDelay and subMenuOpenDelay
- Refactor with rc-trigger

## 5.1.0 / 2016-09-12

- Add dom for submenu arrow

## 5.0.0 / 2016-08-19

- remove onOpen/onClose, support onOpenChange(openKeys: string[])

## 4.13.0 / 2016-07-22

- support submenu-selected

## 4.12 / 2016-05-05

- make submenu active only title is hovered when inline

## 4.11.0 / 2016-04-27

- add onMouseEnter/onTitleMouseLeave/onTitleClick/...

## 4.10.0 / 2016-01-20

- use es6 export

## 4.9.0 / 2015-12-25
- add keyPath to onOpen/onClose argument info

## 4.6.0 / 2015-09-16
- add keyPath to onClick argument info

## 4.5.0 / 2015-09-14
- does not hide submenu when click(use onClick to set openKeys to [] if you want)

## 4.4.0 / 2015-08-13
- add openAnimation/openTransitionName prop

## 4.3.0 / 2015-08-13
- make selectedKeys openedKeys controllable
- add closeSubMenuOnMouseLeave/onOpen/onClose props

## 4.1.0 / 2015-08-11
- remove openOnHover for SubMenu
- add openSubMenuOnMouseEnter prop for Menu

## 4.0.0 / 2015-08-10

- add props: mode (horizontal, vertical, inline) for Menu
- add defaultSelectedKeys, make selectedKeys controllable
- change param of onSelect onDeselect

## 3.5.0 / 2015-08-06

add props: vertical/horizontal for Menu, align for SubMenu

## 3.4.0 / 2015-06-17

`improved` [#9](https://github.com/react-component/menu/issues/9) allow not set key for menuitem

`new` [#10](https://github.com/react-component/menu/issues/10) support MenuItemGroup

## 3.3.0 / 2015-06-08

`new` add Menu.Divider Component

## 3.1.0 / 2015-03-26

`improved` [#5](https://github.com/react-component/menu/issues/5) support selected and disabled for menuitem simultaneously

## 3.0.0 / 2015-03-17

support react 0.13 and es6

## 2.2.0 / 2015-01-29

`new` [#3](https://github.com/react-component/menu/issues/3) support scrollIntoView if menu is scrollable

`new` [#2](https://github.com/react-component/menu/issues/2) support multiple prop and onDeselect callback
